# CHANGELOG


## 23.2 (2023-11-20)

Prevent the MigrationAutoDetector from removing the user unique email constraint if
running `makemigrations` on the `auth` app.

Thanks to Matteo Vitali.


## 23.1 (2023-10-06)

Initial Version

